@@ -7,4 +7,4 @@ bag-of-word counts.
 from ldamodel import LdaModel
 from lsimodel import LsiModel
 from tfidfmodel import TfidfModel
-#from rpmodel import RpModel
+from rpmodel import RpModel
